# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/bixo/niche/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/bixo/niche/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Bixo\\Niche\\": "packages/bixo/niche/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Bixo\Niche\Providers\NicheServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Niche'  => Bixo\Niche\Facades\Niche::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Bixo\\NicheTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Bixo\Niche\Providers\NicheServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Bixo\Niche\Providers\NicheServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Bixo\Niche\Providers\NicheServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/niche/{modulename}

**User**

    http://path-to-route-folder/user/niche/{modulename}

**Public**

    http://path-to-route-folder/niches


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/niche/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/niche/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/niche/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/niche/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/niche/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/niche/{modulename}/{slug}
    METHOD: GET